@@ -5,6 +5,8 @@ from .._impl import (
     api_rids_ChunkRid as ChunkRid,
     api_rids_DataSourceRid as DataSourceRid,
     api_rids_DatasetRid as DatasetRid,
+    api_rids_EdgeSyncSourceRid as EdgeSyncSourceRid,
+    api_rids_EdgeSyncTargetRid as EdgeSyncTargetRid,
     api_rids_EventRid as EventRid,
     api_rids_NominalDataSourceOrDatasetRid as NominalDataSourceOrDatasetRid,
     api_rids_NominalDataSourceRid as NominalDataSourceRid,
@@ -23,6 +25,8 @@ __all__ = [
     'ChunkRid',
     'DataSourceRid',
     'DatasetRid',
+    'EdgeSyncSourceRid',
+    'EdgeSyncTargetRid',
     'EventRid',
     'NominalDataSourceOrDatasetRid',
     'NominalDataSourceRid',
