@@ -3,3 +3,7 @@ from .._impl import (
     datasource_logset_LogSetService as LogSetService,
 )
 
+__all__ = [
+    'LogSetService',
+]
+
