@@ -42,12 +42,24 @@ from .._impl import (
     scout_chartdefinition_api_FrequencyChartDefinitionV1 as FrequencyChartDefinitionV1,
     scout_chartdefinition_api_FrequencyChartDefinitionVisitor as FrequencyChartDefinitionVisitor,
     scout_chartdefinition_api_FrequencyPlot as FrequencyPlot,
+    scout_chartdefinition_api_Geo3dDefinition as Geo3dDefinition,
+    scout_chartdefinition_api_Geo3dDefinitionV1 as Geo3dDefinitionV1,
+    scout_chartdefinition_api_Geo3dDefinitionVisitor as Geo3dDefinitionVisitor,
+    scout_chartdefinition_api_Geo3dOrientation as Geo3dOrientation,
+    scout_chartdefinition_api_Geo3dOrientationPrincipalAxes as Geo3dOrientationPrincipalAxes,
+    scout_chartdefinition_api_Geo3dOrientationVisitor as Geo3dOrientationVisitor,
+    scout_chartdefinition_api_Geo3dPosition as Geo3dPosition,
+    scout_chartdefinition_api_Geo3dPositionVisitor as Geo3dPositionVisitor,
+    scout_chartdefinition_api_Geo3dPositionWgs84 as Geo3dPositionWgs84,
     scout_chartdefinition_api_GeoAdditionalTileset as GeoAdditionalTileset,
     scout_chartdefinition_api_GeoAdditionalVariable as GeoAdditionalVariable,
     scout_chartdefinition_api_GeoBaseTileset as GeoBaseTileset,
     scout_chartdefinition_api_GeoCustomFeature as GeoCustomFeature,
     scout_chartdefinition_api_GeoCustomFeatureVisitor as GeoCustomFeatureVisitor,
+    scout_chartdefinition_api_GeoLine3dStyle as GeoLine3dStyle,
     scout_chartdefinition_api_GeoLineStyle as GeoLineStyle,
+    scout_chartdefinition_api_GeoPlot3d as GeoPlot3d,
+    scout_chartdefinition_api_GeoPlot3dVisualizationOptions as GeoPlot3dVisualizationOptions,
     scout_chartdefinition_api_GeoPlotFromLatLong as GeoPlotFromLatLong,
     scout_chartdefinition_api_GeoPlotSecondaryVisibilityConfig as GeoPlotSecondaryVisibilityConfig,
     scout_chartdefinition_api_GeoPlotVisualizationOptions as GeoPlotVisualizationOptions,
@@ -149,6 +161,7 @@ from .._impl import (
     scout_chartdefinition_api_ValueTableLayoutGrid as ValueTableLayoutGrid,
     scout_chartdefinition_api_ValueTableLayoutVisitor as ValueTableLayoutVisitor,
     scout_chartdefinition_api_ValueTableMultiCellConfig as ValueTableMultiCellConfig,
+    scout_chartdefinition_api_ValueTableStalenessConfig as ValueTableStalenessConfig,
     scout_chartdefinition_api_ValueToColorMap as ValueToColorMap,
     scout_chartdefinition_api_ValueToColorMapVisitor as ValueToColorMapVisitor,
     scout_chartdefinition_api_VideoPanelDataSource as VideoPanelDataSource,
@@ -203,12 +216,24 @@ __all__ = [
     'FrequencyChartDefinitionVisitor',
     'FrequencyChartDefinitionV1',
     'FrequencyPlot',
+    'Geo3dDefinition',
+    'Geo3dDefinitionVisitor',
+    'Geo3dDefinitionV1',
+    'Geo3dOrientation',
+    'Geo3dOrientationVisitor',
+    'Geo3dOrientationPrincipalAxes',
+    'Geo3dPosition',
+    'Geo3dPositionVisitor',
+    'Geo3dPositionWgs84',
     'GeoAdditionalTileset',
     'GeoAdditionalVariable',
     'GeoBaseTileset',
     'GeoCustomFeature',
     'GeoCustomFeatureVisitor',
+    'GeoLine3dStyle',
     'GeoLineStyle',
+    'GeoPlot3d',
+    'GeoPlot3dVisualizationOptions',
     'GeoPlotFromLatLong',
     'GeoPlotSecondaryVisibilityConfig',
     'GeoPlotVisualizationOptions',
@@ -310,6 +335,7 @@ __all__ = [
     'ValueTableLayoutVisitor',
     'ValueTableLayoutGrid',
     'ValueTableMultiCellConfig',
+    'ValueTableStalenessConfig',
     'ValueToColorMap',
     'ValueToColorMapVisitor',
     'VideoPanelDataSource',
