@@ -32,6 +32,7 @@ from .._impl import (
     scout_comparisonnotebook_api_ComparisonWorkbookDataScope as ComparisonWorkbookDataScope,
     scout_comparisonnotebook_api_ComparisonWorkbookDataScopeVisitor as ComparisonWorkbookDataScopeVisitor,
     scout_comparisonnotebook_api_ComputeNodeWithContext as ComputeNodeWithContext,
+    scout_comparisonnotebook_api_Count as Count,
     scout_comparisonnotebook_api_Max as Max,
     scout_comparisonnotebook_api_Mean as Mean,
     scout_comparisonnotebook_api_Min as Min,
@@ -85,6 +86,7 @@ __all__ = [
     'ComparisonWorkbookDataScope',
     'ComparisonWorkbookDataScopeVisitor',
     'ComputeNodeWithContext',
+    'Count',
     'Max',
     'Mean',
     'Min',
