@@ -41,6 +41,7 @@ from .._impl import (
     scout_compute_resolved_api_EnumTimeRangeFilterSeriesNode as EnumTimeRangeFilterSeriesNode,
     scout_compute_resolved_api_EnumTimeShiftSeriesNode as EnumTimeShiftSeriesNode,
     scout_compute_resolved_api_EnumUnionSeriesNode as EnumUnionSeriesNode,
+    scout_compute_resolved_api_EventSearchNode as EventSearchNode,
     scout_compute_resolved_api_ExponentialCurve as ExponentialCurve,
     scout_compute_resolved_api_ExtremaRangesNode as ExtremaRangesNode,
     scout_compute_resolved_api_FftNode as FftNode,
@@ -199,6 +200,7 @@ __all__ = [
     'EnumTimeRangeFilterSeriesNode',
     'EnumTimeShiftSeriesNode',
     'EnumUnionSeriesNode',
+    'EventSearchNode',
     'ExponentialCurve',
     'ExtremaRangesNode',
     'FftNode',
